Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(107)

Unified Diff: remoting/client/ios/host_preferences.h

Issue 2628403002: Migrating host preferences, runtime, and gestures to chromium from internal. (Closed)
Patch Set: Rename impl to match new header file name. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/client/ios/client_gestures.mm ('k') | remoting/client/ios/host_preferences.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/client/ios/host_preferences.h
diff --git a/remoting/client/ios/host_preferences.h b/remoting/client/ios/host_preferences.h
index 6fb19a0a1276bd8d7299e935dd18a9506854e329..553167b9e72000f52fac4ce13240b3c6d7b1a2f4 100644
--- a/remoting/client/ios/host_preferences.h
+++ b/remoting/client/ios/host_preferences.h
@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -9,7 +9,6 @@
// A HostPreferences contains details to negotiate and maintain a connection
// to a remote Chromoting host. This is an entity in a backing store.
-
@interface HostPreferences : NSObject<NSCoding>
// Properties supplied by the host server.
@@ -17,12 +16,10 @@
@property(nonatomic, copy) NSString* pairId;
@property(nonatomic, copy) NSString* pairSecret;
-// Commit this record using the SSOKeychain
-// for SSOSigninManager's current identity.
-- (void)saveToSSOKeychain;
+// Commit this record using the Keychain for current identity.
+- (void)saveToKeychain;
-// Load a record from the SSOKeychain
-// for SSOSigninManager's current identity.
+// Load a record from the Keychain for current identity.
// If a record does not exist, return a new record with a blank secret.
+ (HostPreferences*)hostForId:(NSString*)hostId;
« no previous file with comments | « remoting/client/ios/client_gestures.mm ('k') | remoting/client/ios/host_preferences.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698